summaryrefslogtreecommitdiff
path: root/src/arch/x86/interrupts.hh
diff options
context:
space:
mode:
Diffstat (limited to 'src/arch/x86/interrupts.hh')
-rw-r--r--src/arch/x86/interrupts.hh4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/arch/x86/interrupts.hh b/src/arch/x86/interrupts.hh
index 959a61513..da0d767fd 100644
--- a/src/arch/x86/interrupts.hh
+++ b/src/arch/x86/interrupts.hh
@@ -72,7 +72,7 @@ namespace X86ISA {
ApicRegIndex decodeAddr(Addr paddr);
-class Interrupts : public BasicPioDevice, IntDev
+class Interrupts : public BasicPioDevice, IntDevice
{
protected:
// Storage for the APIC registers
@@ -215,7 +215,7 @@ class Interrupts : public BasicPioDevice, IntDev
void init();
/*
* Functions to interact with the interrupt port from IntDev.
*/
Tick read(PacketPtr pkt);
Tick write(PacketPtr pkt);
@@ -215,7 +215,7 @@ class Interrupts : public BasicPioDevice, IntDev
void init();
/*
- * Functions to interact with the interrupt port from IntDev.
+ * Functions to interact with the interrupt port from IntDevice.
*/
Tick read(PacketPtr pkt);